==> jc-1.4.0.tar.gz: soot/util/Debug.h <==
// public class soot.util.Debug

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 32eb1b353b35bdb4 soot_util_Debug

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_Debug_H_
#define _JC_soot_util_Debug_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_Debug$sub_refs	_jc_soot_util_Debug$sub_refs;
typedef struct _jc_soot_util_Debug$sub_nonrefs	_jc_soot_util_Debug$sub_nonrefs;
typedef struct _jc_soot_util_Debug$refs	_jc_soot_util_Debug$refs;
typedef struct _jc_soot_util_Debug$nonrefs	_jc_soot_util_Debug$nonrefs;
typedef struct _jc_soot_util_Debug$object	_jc_soot_util_Debug$object;

typedef const struct _jc_soot_util_Debug$vmethods	_jc_soot_util_Debug$vmethods;
typedef const struct _jc_soot_util_Debug$vtable	_jc_soot_util_Debug$vtable;
typedef const struct _jc_soot_util_Debug$vtype	_jc_soot_util_Debug$vtype;

// Constructors
extern void _jc_soot_util_Debug$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_Debug$object *);

// Static methods
extern struct _jc_java_lang_String$object *_jc_soot_util_Debug$method$getStackTrace$56d1500724703e04(_jc_env *);

// Virtual methods structure
struct _jc_soot_util_Debug$vmethods {
};

// Vtable
struct _jc_soot_util_Debug$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_Debug$vmethods	soot_util_Debug;
};

// Vtype
struct _jc_soot_util_Debug$vtype {
	_jc_type			type;
	_jc_soot_util_Debug$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_Debug$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_Debug$refs {
    _jc_soot_util_Debug$sub_refs	soot_util_Debug;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_Debug$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_Debug$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_Debug$sub_nonrefs	soot_util_Debug;
};

// Object instance structure
struct _jc_soot_util_Debug$object {
	_jc_soot_util_Debug$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_Debug$vtype	*vtype;
	_jc_soot_util_Debug$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_Debug$vtype _jc_soot_util_Debug$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_Debug, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_Debug$class_object;

#endif	/* _JC_soot_util_Debug_H_ */

==> jc-1.4.6.tar.gz: soot/util/Debug.h <==
// public class soot.util.Debug

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 32eb1b353b35bdb4 soot_util_Debug

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_Debug_H_
#define _JC_soot_util_Debug_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_Debug$sub_refs	_jc_soot_util_Debug$sub_refs;
typedef struct _jc_soot_util_Debug$sub_nonrefs	_jc_soot_util_Debug$sub_nonrefs;
typedef struct _jc_soot_util_Debug$refs	_jc_soot_util_Debug$refs;
typedef struct _jc_soot_util_Debug$nonrefs	_jc_soot_util_Debug$nonrefs;
typedef struct _jc_soot_util_Debug$object	_jc_soot_util_Debug$object;

typedef const struct _jc_soot_util_Debug$vmethods	_jc_soot_util_Debug$vmethods;
typedef const struct _jc_soot_util_Debug$vtable	_jc_soot_util_Debug$vtable;
typedef const struct _jc_soot_util_Debug$vtype	_jc_soot_util_Debug$vtype;

// Constructors
extern void _jc_soot_util_Debug$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_Debug$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_String$object *_jc_soot_util_Debug$method$getStackTrace$56d1500724703e04(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_Debug$vmethods {
};

// Vtable
struct _jc_soot_util_Debug$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_Debug$vmethods	soot_util_Debug;
};

// Vtype
struct _jc_soot_util_Debug$vtype {
	_jc_type			type;
	_jc_soot_util_Debug$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_Debug$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_Debug$refs {
    _jc_soot_util_Debug$sub_refs	soot_util_Debug;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_Debug$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_Debug$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_Debug$sub_nonrefs	soot_util_Debug;
};

// Object instance structure
struct _jc_soot_util_Debug$object {
	_jc_soot_util_Debug$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_Debug$vtype	*vtype;
	_jc_soot_util_Debug$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_Debug$vtype _jc_soot_util_Debug$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_Debug, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_Debug$class_object;

#endif	/* _JC_soot_util_Debug_H_ */
